﻿using System.Linq;
using System.DirectoryServices.AccountManagement;
using System;

namespace TestProject
{
    /// <summary>
    /// 액티브 디렉토리 헬퍼
    /// </summary>
    public static class ActiveDirectoryHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 액티브 디렉토리 사용자 계정 여부 구하기 - IsAactiveDirectoryUserID(domain, userID)

        /// <summary>
        /// 액티브 디렉토리 사용자 계정 여부 구하기
        /// </summary>
        /// <param name="domain">도메인</param>
        /// <param name="userID">사용자 ID</param>
        /// <returns>액티브 디렉토리 사용자 계정 여부</returns>
        public static bool IsAactiveDirectoryUserID(string domain, string userID)
        {
            try
            {
                using(PrincipalContext context = new PrincipalContext(ContextType.Domain, domain))
                {
                    using(UserPrincipal user = new UserPrincipal(context))
                    {
                        user.SamAccountName = userID;
 
                        using(PrincipalSearcher searcher = new PrincipalSearcher())
                        {
                            searcher.QueryFilter = user;
 
                            using(PrincipalSearchResult<Principal> result = searcher.FindAll())
                            {
                                if(result != null && result.Count() > 0)
                                {
                                    return true;
                                }
                            }
                        }
                    }
                }
 
                return false;
            }
            catch(Exception)
            {
                return false;
            }
        }

        #endregion
    }
}